==> ehome-rcm-0.12.3.tgz: package/es/region-code/components/SearchRegionCode/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { PureComponent, Component } from 'react';

var SearchRegionCode =
/*#__PURE__*/
function (_ref) {
  _inherits(SearchRegionCode, _ref);

  function SearchRegionCode() {
    _classCallCheck(this, SearchRegionCode);

    return _possibleConstructorReturn(this, _getPrototypeOf(SearchRegionCode).apply(this, arguments));
  }

  _createClass(SearchRegionCode, [{
    key: "render",
    value: function render() {
      var prefixCls = 'eh-region-code';
      var _this$props = this.props,
          regionCodeList = _this$props.regionCodeList,
          searchText = _this$props.searchText,
          onSelect = _this$props.onSelect;
      var filtedList = regionCodeList.filter(function (item) {
        return item.name.indexOf(searchText) > -1 || item.regionCode.indexOf(searchText) > -1;
      });
      return React.createElement("div", {
        className: "".concat(prefixCls, "-search-list")
      }, filtedList.length === 0 ? React.createElement("div", {
        className: "".concat(prefixCls, "-empty")
      }, "\u6CA1\u6709\u627E\u5230\u76F8\u5173\u7ED3\u679C") : React.createElement("div", null, filtedList.map(function (item) {
        var id = item.id,
            name = item.name,
            regionCode = item.regionCode;
        return React.createElement("div", {
          className: "".concat(prefixCls, "-item"),
          key: id,
          onClick: function onClick(e) {
            return onSelect && onSelect(item, e);
          }
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-item-name")
        }, name), React.createElement("span", {
          className: "".concat(prefixCls, "-item-region-code")
        }, " ", regionCode));
      })));
    }
  }]);

  return SearchRegionCode;
}(PureComponent || Component);

export default SearchRegionCode;

==> ehome-rcm-0.15.2.tgz: package/es/region-code/components/SearchRegionCode/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React, { PureComponent, Component } from 'react';

var SearchRegionCode = /*#__PURE__*/function (_ref) {
  _inherits(SearchRegionCode, _ref);

  var _super = _createSuper(SearchRegionCode);

  function SearchRegionCode() {
    _classCallCheck(this, SearchRegionCode);

    return _super.apply(this, arguments);
  }

  _createClass(SearchRegionCode, [{
    key: "render",
    value: function render() {
      var prefixCls = 'eh-region-code';
      var _this$props = this.props,
          regionCodeList = _this$props.regionCodeList,
          searchText = _this$props.searchText,
          onSelect = _this$props.onSelect;
      var filtedList = regionCodeList.filter(function (item) {
        return item.name.indexOf(searchText) > -1 || item.regionCode.indexOf(searchText) > -1;
      });
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-search-list")
      }, filtedList.length === 0 ? /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-empty")
      }, "\u6CA1\u6709\u627E\u5230\u76F8\u5173\u7ED3\u679C") : /*#__PURE__*/React.createElement("div", null, filtedList.map(function (item) {
        var id = item.id,
            name = item.name,
            regionCode = item.regionCode;
        return /*#__PURE__*/React.createElement("div", {
          className: "".concat(prefixCls, "-item"),
          key: id,
          onClick: function onClick(e) {
            return onSelect && onSelect(item, e);
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat(prefixCls, "-item-name")
        }, name), /*#__PURE__*/React.createElement("span", {
          className: "".concat(prefixCls, "-item-region-code")
        }, " ", regionCode));
      })));
    }
  }]);

  return SearchRegionCode;
}(PureComponent || Component);

export default SearchRegionCode;
